@@ -98,11 +98,12 @@ class Accountant:
         return operation
 
     @staticmethod
-    def create_book(account_id):
+    def create_book(account_id: str):
         log.info("---------New_ledger-------------")
-        block_book_id = account_id.ledger.create_book(name=f"{account_id.bank_account['account_id']}_block_book",
+        ledger = LedgerClient(ledger_host="http://ledger-service-dev-1.local-dev:3000/")
+        block_book_id = ledger.create_book(name=f"{account_id}_block_book",
                                                 min_balance="-100")
-        main_book_id = account_id.ledger.create_book(name=f"{account_id.bank_account['account_id']}_main_book", min_balance="-100")
+        main_book_id = ledger.create_book(name=f"{account_id}_main_book", min_balance="-100")
         new_books = {
             'main_balance': {'name': main_book_id['name'],
                              'id': main_book_id['id']},
